two_paragraphs.pdf

## Metadata

Title | two_paragraphs.pdf
Path | C:\Users\jenni\OneDrive\Documents\Code\burdoc\burdoc\tests\integration\data\inputs\two_paragraphs.pdf
Pages | 0
PDF Metadata: format | PDF 1.7
PDF Metadata: title |
PDF Metadata: author | Joe Ennis
PDF Metadata: subject |
PDF Metadata: keywords |
PDF Metadata: creator | Microsoft® Word for Microsoft 365
PDF Metadata: producer | Microsoft® Word for Microsoft 365
PDF Metadata: creationDate | D:20230325084634+00'00'
PDF Metadata: modDate | D:20230325084634+00'00'
PDF Metadata: trapped |
PDF Metadata: encryption |

## Contents

1. Page 0

#### Page 0

No images

Path: | content.0.[0,0].bbox
Type: | addition

Key | Old | New
x1 |  | 521.8580932617188
y1 |  | 154.70773315429688
y0 |  | 73.70773315429688
x0 |  | 72.02400207519531

Path: | content.0.[1,1].bbox
Type: | addition

Key | Old | New
x1 |  | 521.6400146484375
y1 |  | 279.1777038574219
y0 |  | 170.54769897460938
x0 |  | 72.02400207519531

Lorem ipsum dolor sit amet, consectetur adipiscing elit. Curabitur egestas tellus ut ante dictum accumsan. Curabitur vel imperdiet tortor, vestibulum accumsan libero. Ut ac elementum nulla. Ut sit amet faucibus risus. Curabitur maximus urna non lectus bibendum finibus. Duis eget eleifend sapien. Suspendisse potenti. Donec neque lorem, scelerisque non sollicitudin sed, molestie a eros. Donec sed turpis sit amet dui vestibulum fringilla. Integer ut enim sit amet sem vestibulum efficitur et vel ante.

Suspendisse commodo condimentum dolor, eu consectetur dui posuere sed. Curabitur eros sem, venenatis consectetur ultricies in, vehicula sodales felis. Donec sem est, pulvinar ac justo sed, posuere malesuada justo. Vivamus sagittis at tortor vitae sodales. Donec sit amet egestas nulla. Cras eget auctor libero. Donec at maximus metus. Aliquam nec dolor euismod, lobortis purus et, rhoncus sem. Phasellus a dolor et lacus dapibus efficitur. Cras diam mi, consectetur vitae blandit a, consectetur ac mi. Etiam arcu eros, finibus eget elementum ut, ultricies nec metus. Ut eget sagittis turpis, a dignissim orci. Nunc vestibulum dui sed commodo congue. Praesent ultrices mattis tortor.

Lorem ipsum dolor sit amet, consectetur adipiscing elit. Curabitur egestas tellus ut ante dictum accumsan. Curabitur vel imperdiet tortor, vestibulum accumsan libero. Ut ac elementum nulla. Ut sit amet faucibus risus. Curabitur maximus urna non lectus bibendum finibus. Duis eget eleifend sapien. Suspendisse potenti. Donec neque lorem, scelerisque non sollicitudin sed, molestie a eros. Donec sed turpis sit amet dui vestibulum fringilla. Integer ut enim sit amet sem vestibulum efficitur et vel ante.

Suspendisse commodo condimentum dolor, eu consectetur dui posuere sed. Curabitur eros sem, venenatis consectetur ultricies in, vehicula sodales felis. Donec sem est, pulvinar ac justo sed, posuere malesuada justo. Vivamus sagittis at tortor vitae sodales. Donec sit amet egestas nulla. Cras eget auctor libero. Donec at maximus metus. Aliquam nec dolor euismod, lobortis purus et, rhoncus sem. Phasellus a dolor et lacus dapibus efficitur. Cras diam mi, consectetur vitae blandit a, consectetur ac mi. Etiam arcu eros, finibus eget elementum ut, ultricies nec metus. Ut eget sagittis turpis, a dignissim orci. Nunc vestibulum dui sed commodo congue. Praesent ultrices mattis tortor.

Parent File Contents